Deployment
**********

Here we describe how to deploy a project named "foobar" to production. We are using
cookiecutter-django_ for convenience, but this should also be possible with other project
bootstrapping mechanisms.

Contents:

.. toctree::
   :maxdepth: 2

   local_install
   production_services
   heroku
   ec2_install

.. _`cookiecutter-django`: https://github.com/pydanny/cookiecutter-django
